@@ -1,23 +1,9 @@
 /*
  * This file is part of LibKGAPI library
  *
- * Copyright (C) 2013  Daniel Vrátil <dvratil@redhat.com>
+ * SPDX-FileCopyrightText: 2013 Daniel Vrátil <dvratil@redhat.com>
  *
- * This library is free software; you can redistribute it and/or
- * modify it under the terms of the GNU Lesser General Public
- * License as published by the Free Software Foundation; either
- * version 2.1 of the License, or (at your option) version 3, or any
- * later version accepted by the membership of KDE e.V. (or its
- * successor approved by the membership of KDE e.V.), which shall
- * act as a proxy defined in Section 6 of version 3 of the license.
- *
- * This library is distributed in the hope that it will be useful,
- * but WITHOUT ANY WARRANTY; without even the implied warranty of
- * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
- * GNU Lesser General Public License for more details.
- *
- * You should have received a copy of the GNU Lesser General Public
- * License along with this library.  If not, see <https://www.gnu.org/licenses/>.
+ * SPDX-License-Identifier: LGPL-2.1-only OR LGPL-3.0-only OR LicenseRef-KDE-Accepted-LGPL
  */
 
 #include "calendarservice.h"
@@ -187,7 +173,7 @@ QUrl removeEventUrl(const QString& calendarID, const QString& eventID)
 QUrl moveEventUrl(const QString& sourceCalendar, const QString& destCalendar, const QString& eventID)
 {
     QUrl url(Private::GoogleApisUrl);
-    url.setPath(Private::CalendarBasePath % QLatin1Char('/') % sourceCalendar % QLatin1String("/events/") % eventID);
+    url.setPath(Private::CalendarBasePath % QLatin1Char('/') % sourceCalendar % QLatin1String("/events/") % eventID % QLatin1String("/move"));
     QUrlQuery query(url);
     query.addQueryItem(destinationQueryParam, destCalendar);
     url.setQuery(query);
@@ -207,6 +193,7 @@ static const auto kindParam = QStringLiteral("kind");
 static const auto idParam = QStringLiteral("id");
 static const auto etagParam = QStringLiteral("etag");
 
+static const auto nextSyncTokenParam = QStringLiteral("nextSyncToken");
 static const auto nextPageTokenParam = QStringLiteral("nextPageToken");
 static const auto pageTokenParam = QStringLiteral("pageToken");
 static const auto itemsParam = QStringLiteral("items");
@@ -807,6 +794,9 @@ ObjectsList parseEventJSONFeed(const QByteArray& jsonFeed, FeedData& feedData)
             // This should always be in Olson format
             timezone = data.value(timeZoneParam).toString();
         }
+        if (data.contains(nextSyncTokenParam)) {
+            feedData.syncToken = data[nextSyncTokenParam].toString();
+        }
     } else {
         return {};
     }
