@@ -1,21 +1,7 @@
 /*
- * Copyright 2015  Daniel Vrátil <dvratil@redhat.com>
+ * SPDX-FileCopyrightText: 2015 Daniel Vrátil <dvratil@redhat.com>
  *
- * This library is free software; you can redistribute it and/or
- * modify it under the terms of the GNU Lesser General Public
- * License as published by the Free Software Foundation; either
- * version 2.1 of the License, or (at your option) version 3, or any
- * later version accepted by the membership of KDE e.V. (or its
- * successor approved by the membership of KDE e.V.), which shall
- * act as a proxy defined in Section 6 of version 3 of the license.
- *
- * This library is distributed in the hope that it will be useful,
- * but WITHOUT ANY WARRANTY; without even the implied warranty of
- * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
- * GNU Lesser General Public License for more details.
- *
- * You should have received a copy of the GNU Lesser General Public
- * License along with this library.  If not, see <https://www.gnu.org/licenses/>.
+ * SPDX-License-Identifier: LGPL-2.1-only OR LGPL-3.0-only OR LicenseRef-KDE-Accepted-LGPL
  */
 
 #include "freebusyqueryjob.h"
@@ -115,7 +101,7 @@ void FreeBusyQueryJob::handleReply(const QNetworkReply *reply, const QByteArray
         const QVariantMap data = document.toVariant().toMap();
         const QVariantMap cals = data[QStringLiteral("calendars")].toMap();
         const QVariantMap cal = cals[d->id].toMap();
-        if (cal.contains(QLatin1String("errors"))) {
+        if (cal.contains(QStringLiteral("errors"))) {
             setError(KGAPI2::NotFound);
             setErrorString(tr("FreeBusy information is not available"));
         } else {
